@@ -58,10 +58,11 @@ class Datatxt(object):
         self.headers = {
             'Accept' : 'application/json'
         }
+        self.default_rho = rho
         self.service = sparql.Service(endpoint)
         self.prefix = prefix
 
-    def annotate(self, text, properties=True, wikilinks=False):
+    def annotate(self, text, properties=True, wikilinks=False, rho=None):
         """ return a dictionary out of json
         Example output:
         {u'annotations': [
@@ -85,7 +86,11 @@ class Datatxt(object):
         u'status': 200,
         u'text': u'L\'etimologia della parola che d\xc3\xa0 il nome alla citt\xc3\xa0 di Rovereto  deriva dal latino Roborem e trae dalla stessa radice della parola Robur: forza, robustezza, robusto. In Botanica la parola legno di rovere \xc3\xa8 correlata ad una specie di quercia indigena dell\'Europa, di minore altezza alla quercia ordinaria, ma che fornisce un legno durissimo: Quercus petraea. Nella toponomastica romana "Roboretum" significava selva di querce, albero che abbonda nella valle ed \xc3\xa8 effigie dello stemma comunale.'}
         """
-        self.params['text'] = text
+        params = dict(self.params)
+        params['text'] = text
+        if rho:
+            params['rho'] = rho
+
         r = get(self.api_url, params=self.params, headers=self.headers)
         if r.status_code == 200:
             result = r.json
